@@ -238,7 +238,7 @@ int handle_int_1a(struct vm86plus_struct *v86)
   return 0;
 }
 
-void dump_partition(DWORD seg, DWORD offset)
+static void dump_partition(DWORD seg, DWORD offset)
 {
   BYTE *data = FAR(seg, offset);
   /* Format:
